program test_set_all_outerm

  use, intrinsic:: ISO_FORTRAN_ENV

  ! Libraries:
  use jumble, only: pi

  use config_m, only: config, min_radius
  use derived_types, only: snapshot, shpc_slice_handler, null_ssh_contour, &
       missing_speed
  use input_ssh_m, only: input_ssh
  use set_all_outerm_m, only: set_all_outerm
  use shpc_close_m, only: shpc_close
  use shpc_create_m, only: shpc_create
  use write_eddy_m, only: write_eddy

  implicit none

  type(snapshot) s
  integer nlon, nlat
  integer i, n_cyclo, n_anti

  real, allocatable:: ssh(:, :)
  ! (1 - max_radius(1):nlon + max_radius(1), nlat) if the grid is periodic
  ! in longitude, else (nlon, nlat). Sea-surface height, in m.

  real, allocatable:: u(:, :), v(:, :)
  ! (1 - max_radius(1):nlon + max_radius(1), nlat) if periodic, else
  ! (nlon, nlat) wind, in m s-1

  real corner_deg(2), corner(2)
  ! longitude and latitude of the corner of the whole grid, in degrees
  ! and in rad

  real step_deg(2), step(2) ! longitude and latitude steps, in degrees and rad
  logical periodic ! grid is periodic in longitude
  TYPE(shpc_slice_handler) hshp_cyclo, hshp_anti

  !--------------------------------------------------------------

  call config(exist = .false.)
  call input_ssh(corner, step, nlon, nlat, periodic, ssh, u, v, corner_deg, &
       step_deg)
  call set_all_outerm(s, step, periodic, ssh, corner, &
       min_area = pi * (min_radius * 1e3)**2)

  do i = 1, s%number_extr
     s%list(i)%speed_cont = null_ssh_contour()
     s%list(i)%max_speed = missing_speed
     s%list(i)%radius4 = 0
  end do

  call shpc_create(hshp_cyclo, shpc_dir = "SHPC_cyclo", cyclone = .true.)
  call shpc_create(hshp_anti, shpc_dir = "SHPC_anti", cyclone = .false.)
  n_cyclo = 0
  n_anti = 0

  do i = 1, s%number_extr
     if (s%list(i)%cyclone) then
        n_cyclo = n_cyclo + 1
        call write_eddy(s%list(i), hshp_cyclo, date = 1, i = n_cyclo)
     else
        n_anti = n_anti + 1
        call write_eddy(s%list(i), hshp_anti, date = 1, i = n_anti)
     end if
  end do

  print *, "s%number_extr = ", s%number_extr

  CALL shpc_close(hshp_cyclo)
  CALL shpc_close(hshp_anti)
  print *, 'Created shapefile collections in SHPC_cyclo and SHPC_anti.'
  print *, "Average number of points per outermost contour: ", &
       sum(s%list%out_cont%n_points) / real(s%number_extr)

end program test_set_all_outerm
