module config_m

  implicit none

  real, protected:: min_amp = 0.001
  ! minimum amplitude of ssh, between extremum and outermost contour,
  ! in m

  real, protected:: max_radius_deg(2) = [5., 5.]
  ! maximum radius of an eddy in longitude and latitude, in degrees

  real, protected:: min_radius = 25.
  ! minimum radius of the equal-area disk for an outermost contour, in km

  namelist /main_nml/ min_amp, max_radius_deg, min_radius
  private main_nml, write_nml

contains

  subroutine config(exist)

    ! Libraries:
    use jumble, only: new_unit

    logical, intent(in):: exist ! we are appending to an SHPC

    ! Local:
    integer unit

    !----------------------------------------------------------------------

    call new_unit(unit)
    
    if (exist) then
       open(unit, file = "SHPC_cyclo/used_nml.txt", status = "old", &
            action = "read", position = "rewind")
       read(unit, nml = main_nml)
       close(unit)
    else
       open(unit, file = "main_nml.txt", status = "old", action = "read", &
            position = "rewind")
       read(unit, nml = main_nml)
       close(unit)
       call write_nml(shpc_dir = "SHPC_cyclo")
       call write_nml(shpc_dir = "SHPC_anti")
    end if

  end subroutine config

  !*********************************************************************

  subroutine write_nml(shpc_dir)

    use, intrinsic:: ISO_FORTRAN_ENV

    ! Libraries:
    use jumble, only: new_unit

    character(len = *), intent(in):: shpc_dir

    ! Local:
    integer unit, iostat
    character(len = 200) iomsg

    !----------------------------------------------------------------------

    call new_unit(unit)
    open(unit, file = shpc_dir // "/used_nml.txt", status = "replace", &
         action = "write", iostat = iostat, iomsg = iomsg)
    ! (This also allows us to verify that the directory shpc_dir exists.)

    if (iostat /= 0) then
       write(unit = error_unit, fmt = *) "write_nml: ", trim(iomsg)
       write(unit = error_unit, fmt = *) 'write_nml: ', &
            'Have you created the directory "', shpc_dir, '"?'
       stop 1
    end if

    write(unit, nml = main_nml)
    close(unit)

  end subroutine write_nml

end module config_m
